@@ -1,5 +1,5 @@
 from .config_enum import ConfigCategory,ConfigEnum
-from .config import StrConfig,BoolConfig,get_hconfigs,get_hdomains,hconfig,hdomain
+from .config import StrConfig,BoolConfig,get_hconfigs,get_hdomains,hconfig,hdomain,set_hconfig
 
 from .domain import Domain,DomainType,ShowDomain
 from .proxy import Proxy
