@@ -34,6 +34,7 @@ class ConfigCategory(StrEnum):
     advanced=auto()
 
 class ConfigEnum(StrEnum):
+    package_mode=auto()
     telegram_bot_token=auto()
     is_parent=auto()
     parent_panel=auto()
@@ -100,6 +101,7 @@ class ConfigEnum(StrEnum):
       return cls.not_found #"key not found"
     def info(self):
         map = {
+            self.package_mode: {'category': ConfigCategory.advanced,'show_in_parent':True},
             self.telegram_bot_token: {'category': ConfigCategory.advanced,'show_in_parent':True},
             self.is_parent:{'category': ConfigCategory.hidden,'type':bool},
             self.parent_panel:{'category': ConfigCategory.advanced},
