@@ -63,7 +63,7 @@ def init_db():
         print(Child.query.filter(Child.id==0).first())
         db.session.add(Child(unique_id="self",id=0))
         db.session.commit()
-    db_actions={1:_v1,2:_v2,3:_v3,6:_v6,8:_v8,9:_v9,10:_v10,11:_v11,12:_v12}
+    db_actions={1:_v1,2:_v2,3:_v3,6:_v6,8:_v8,9:_v9,10:_v10,11:_v11,12:_v12,13:_v13}
     for ver,db_action in db_actions.items():
         if ver<=db_version:continue
         if start_version==0 and ver==10:continue
@@ -79,6 +79,10 @@ def init_db():
     db.session.commit()
     return BoolConfig.query.all()
 
+def _v13():
+    db.session.add(StrConfig(key=ConfigEnum.telegram_bot_token,value="",child_id=0))
+    db.session.add(StrConfig(key=ConfigEnum.package_mode,value="release",child_id=0))
+
 def _v12():
     db.engine.execute(f'drop TABLE child')
     db.create_all()
